@@ -3,6 +3,7 @@ from .database import check_errors
 from .database import connect_database
 from .database import connect_database
 from .database import count
+from .database import delete
 from .database import insert
 from .database import make_tables
 from .database import select
@@ -27,10 +28,12 @@ from .submissions import search_submissions
 from .submissions import submissions_fields
 from .submissions import submissions_indexes
 from .submissions import submissions_table
-from .users import edit_user_folder_add
-from .users import edit_user_folder_remove
-from .users import edit_user_replace
+from .update import update_database
+from .users import edit_user_field_add
+from .users import edit_user_field_remove
+from .users import edit_user_field_replace
 from .users import exist_user
+from .users import exist_user_field_value
 from .users import new_user
 from .users import remove_user
 from .users import users_fields
