@@ -382,6 +382,11 @@ def update_3_1_to_3_2(db: Connection) -> Connection:
     return connect_database("FA.db")
 
 
+def update_to_current(db: Connection) -> Connection:
+    write_setting(db, "VERSION", __version__)
+    return db
+
+
 def update_database(db: Connection) -> Connection:
     if not (db_version := get_version(db)):
         raise Exception("Cannot read version from database.")
@@ -389,16 +394,15 @@ def update_database(db: Connection) -> Connection:
         return db
     elif v > 0:
         raise Exception("Database version is newer than program.")
-    elif compare_versions(db_version, "2.7.0") == 0:
-        db = update_2_7_to_3(db)
-        db = update_3_to_3_1(db)
-        db = update_3_1_to_3_2(db)
-    elif compare_versions(db_version, "3.0.0") == 0:
-        db = update_3_to_3_1(db)
-        db = update_3_1_to_3_2(db)
-    elif compare_versions(db_version, "3.1.0") == 0:
-        db = update_3_1_to_3_2(db)
-    elif compare_versions(db_version, "2.7.0") < 0:
+    elif (v := compare_versions(db_version, "2.7.0")) < 0:
         raise Exception("Update does not support versions lower than 2.11.2")
+    elif v >= 0 and (v := compare_versions(db_version, "3.0.0")) < 0:
+        return update_database(update_2_7_to_3(db))
+    elif v >= 0 and (v := compare_versions(db_version, "3.1.0")) < 0:
+        return update_database(update_3_to_3_1(db))
+    elif v >= 0 and (v := compare_versions(db_version, "3.2.0")) < 0:
+        return update_database(update_3_1_to_3_2(db))
+    elif v and compare_versions(db_version, __version__) < 0:
+        return update_to_current(db)
 
     return db
